@@ -1,7 +1,7 @@
 """Top-level package for httpx-auth-awssigv4."""
 
-from ._auth import SigV4Auth
+from .auth import SigV4Auth
 
 __author__ = """Mohan Muppidi"""
 __email__ = 'mkumar2301@gmail.com'
-__version__ = '0.1.3'
+__version__ = '0.1.4'
